@@ -37,7 +37,7 @@
 #' @export
 #'
 
-IICAL<-function(Parent,Child,af,rare=NULL,allelename=FALSE,phi=0.25){
+IICAL<-function(Parent,Child,af,rare=0.0001,allelename=FALSE,phi=0.25){
   if (ncol(Parent)!=2 || ncol(Child)!=2 || nrow(Parent)!=nrow(Child)) {
     stop(paste("false in individual data"))
   }
@@ -50,6 +50,9 @@ IICAL<-function(Parent,Child,af,rare=NULL,allelename=FALSE,phi=0.25){
     pc<-af[as.character(Child$P),]
     pd<-af[as.character(Child$M),]
   } else {
+    if (!is.numeric(Child$P) || !is.numeric(Child$M)) {
+      stop("Error: When 'allelename' is FALSE, 'Child' must contain numeric allele positions. Please check your input data or simulation settings.")
+    }
     pc<-af[Child$P,]
     pd<-af[Child$M,]
   }
