@@ -46,7 +46,7 @@
 #' 
 #' 
 
-LRgpgcam<-function(A,C,GP,af,rare=NULL,allelename=FALSE,M=NULL){
+LRgpgcam<-function(A,C,GP,af,rare=0.0001,allelename=FALSE,M=NULL){
   if (ncol(A)!=2 || ncol(C)!=2 || ncol(GP)!=2 || nrow(A)!=nrow(C) || nrow(A)!=nrow(GP) || nrow(C)!=nrow(GP)) {
     stop("false in individual data")
   }
@@ -56,6 +56,9 @@ LRgpgcam<-function(A,C,GP,af,rare=NULL,allelename=FALSE,M=NULL){
     pc<-af[as.character(C[,1]),]
     pd<-af[as.character(C[,2]),]
   } else {
+    if (!is.numeric(A[, 1]) || !is.numeric(A[, 2]) || !is.numeric(C[, 1]) || !is.numeric(C[, 2])) {
+      stop("Error in LRgpgcam: When 'allelename' is FALSE, data A and C must be numeric allele positions. Please check your input data or simulation settings.")
+    }
     pa<-af[A[,1],]
     pb<-af[A[,2],]
     pc<-af[C[,1],]
