@@ -42,7 +42,7 @@
 #'      xlim = c(xmin,xmax), col = "blue")
 #'
 
-LRhsip<-function(A,B,P,af,rare=NULL,allelename=FALSE,phi=0.5){
+LRhsip<-function(A,B,P,af,rare=0.0001,allelename=FALSE,phi=0.5){
   if (ncol(A)!=2 || ncol(B)!=2 || ncol(P)!=2 || nrow(A)!=nrow(B) || nrow(A)!=nrow(P) || nrow(B)!=nrow(P)) {
     stop("false in individual data")
   }
@@ -63,6 +63,9 @@ LRhsip<-function(A,B,P,af,rare=NULL,allelename=FALSE,phi=0.5){
     pc<-af[as.character(B[,1]),]
     pd<-af[as.character(B[,2]),]
   } else {
+    if (!is.numeric(A[, 1]) || !is.numeric(A[, 2]) || !is.numeric(B[, 1]) || !is.numeric(B[, 2])) {
+      stop("Error in LRhsip: When 'allelename' is FALSE, data A and B must be numeric allele positions. Please check your input data or simulation settings.")
+    }
     pa<-af[A[,1],]
     pb<-af[A[,2],]
     pc<-af[B[,1],]
