@@ -19,9 +19,10 @@
 #' AB = pairsimu(af = af,ss = 10000,delta = c(0,1,0),allelename = FALSE)
 #' LRelements<-LRparas(AB=AB, af=af, rare=FortytwoSTR$rare[1][1,1],allelename=FALSE,
 #'   stepwisePI=TRUE,bred=TRUE)
+#' head(LRelements)
 #'
 
-LRparas<-function(AB,af=NULL,rare=NULL,allelename=FALSE,stepwisePI=FALSE,bred=FALSE,mu=0.002){
+LRparas<-function(AB,af=NULL,rare=0.0001,allelename=FALSE,stepwisePI=FALSE,bred=FALSE,mu=0.002){
   if (ncol(AB)!=4) {
     stop(paste("false in individual data"))
   }
@@ -74,6 +75,9 @@ LRparas<-function(AB,af=NULL,rare=NULL,allelename=FALSE,stepwisePI=FALSE,bred=FA
         para$LD6<-cd/pc
       }
     } else {
+      if (!is.numeric(AB[, 3]) || !is.numeric(AB[, 4])) {
+        stop("Error in LRparas: When 'allelename' is FALSE, columns 3 and 4 of the 'AB' data frame must contain numeric allele positions. Please check your input data or simulation settings.")
+      }
       pc<-af[AB[,3],]
       pd<-af[AB[,4],]
       pc[is.na(pc)]<-rare
