@@ -27,7 +27,7 @@
 #' adelta3=adelta3,adelta9=adelta9)
 #' results$total_results_of_the_case
 
-logLR<-function(AB,afmatrix=NULL,rare=NULL,allelename=FALSE,stepPI=FALSE,
+logLR<-function(AB,afmatrix=NULL,rare=0.0001,allelename=FALSE,stepPI=FALSE,
                 adelta3=NULL,adelta9=NULL,mu=0.002){
   if (ncol(AB)!=4) {
     stop(paste("false in individual data"))
@@ -74,6 +74,9 @@ logLR<-function(AB,afmatrix=NULL,rare=NULL,allelename=FALSE,stepPI=FALSE,
         }
       }
     } else{
+      if (!is.numeric(AB[, 1]) || !is.numeric(AB[, 2]) || !is.numeric(AB[, 3]) || !is.numeric(AB[, 4])) {
+        stop("Error in LRhsip: When 'allelename' is FALSE, data AB must be numeric allele positions. Please check your input data or simulation settings.")
+      }
       for (i in 1:nl) {
         para$pc[i]<-afmatrix[[rownames(AB)[i]]][AB[i,3],]
         para$pd[i]<-afmatrix[[rownames(AB)[i]]][AB[i,4],]
@@ -152,6 +155,9 @@ logLR<-function(AB,afmatrix=NULL,rare=NULL,allelename=FALSE,stepPI=FALSE,
             }
           }
         } else{
+          if (!is.numeric(AB[, 1]) || !is.numeric(AB[, 2]) || !is.numeric(AB[, 3]) || !is.numeric(AB[, 4])) {
+            stop("Error in LRhsip: When 'allelename' is FALSE, data AB must be numeric allele positions. Please check your input data or simulation settings.")
+          }
           for (i in 1:nl) {
             para$pa[i]<-afmatrix[[rownames(AB)[i]]][AB[i,1],]
             if(is.na(para$pa[i])){
@@ -214,6 +220,9 @@ logLR<-function(AB,afmatrix=NULL,rare=NULL,allelename=FALSE,stepPI=FALSE,
             }
           }
         } else{
+          if (!is.numeric(AB[, 1]) || !is.numeric(AB[, 2]) || !is.numeric(AB[, 3]) || !is.numeric(AB[, 4])) {
+            stop("Error in LRhsip: When 'allelename' is FALSE, data AB must be numeric allele positions. Please check your input data or simulation settings.")
+          }
           for (i in 1:nl) {
             para$pa[i]<-afmatrix[[rownames(AB)[i]]][AB[i,1],]
             if(is.na(para$pa[i])){
